#ifndef CalendarEventModel_h
#define CalendarEventModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file CalendarEventModel.h
\brief calendar events
\author Hugo Pereira
\version $Revision$
\date $Date$
*/

#include "CalendarEvent.h"
#include "ListModel.h"

namespace Calendar
{

    //* model
    class CalendarEventModel: public ListModel<CalendarEvent>, private Base::Counter<CalendarEventModel>
    {

        Q_OBJECT

        public:

        //* column type enumeration
        enum { nColumns = 1 };

        //* constructor
        explicit CalendarEventModel( QObject* parent = nullptr ):
            ListModel<CalendarEvent>( parent ),
            Counter( "LogbookStatisticsDialog::Model" )
        {}

        //*@name methods reimplemented from base class
        //@{

        //* flags
        Qt::ItemFlags flags(const QModelIndex &index) const override
        {
            if( !get( index ).hasFlag( CalendarEvent::Valid ) ) return Qt::ItemIsSelectable;
            else return Qt::ItemIsEnabled |  Qt::ItemIsSelectable;
        }

        //* return data
        QVariant data(const QModelIndex&, int) const override;

        //* header data
        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;

        //* number of columns for a given index
        int columnCount(const QModelIndex& = QModelIndex()) const override
        { return nColumns; }

        //@}

        protected:

        //* sort
        void _sort( int column, Qt::SortOrder order ) override;

        private:

        //* column names
        const std::array<QString,nColumns> columnTitles_ = {{ tr( "Event" ) }};

    };

}

#endif
