/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CalendarToolTipWidget.h"

#include "Debug.h"
#include "QtUtil.h"

#include <QLayout>

namespace Calendar
{
    //_________________________________________
    class CalendarToolTipWidgetItem: public QWidget, private Base::Counter<CalendarToolTipWidgetItem>
    {

        Q_OBJECT

        public:

        //* construtor
        explicit CalendarToolTipWidgetItem( QWidget*, const CalendarEvent& );

        //* destructor
        virtual ~CalendarToolTipWidgetItem() = default;

    };

}

// need to be included after definition of CalendarToolTipWidgetItem
#include "CalendarToolTipWidget.moc"

namespace Calendar
{

    //_________________________________________
    CalendarToolTipWidgetItem::CalendarToolTipWidgetItem( QWidget* parent, const CalendarEvent& event ):
        QWidget( parent ),
        Counter( "Calendar::CalendarToolTipWidgetItem" )
    {

        QVBoxLayout* vLayout = new QVBoxLayout;
        setLayout( vLayout );
        vLayout->setMargin( 0 );
        vLayout->setSpacing( 5 );

        // date
        QLabel* label = new QLabel( event.firstDateString(), this );
        label->setAlignment( Qt::AlignCenter );
        vLayout->addWidget( label );

        QString second( event.secondDateString() );
        if( !second.isEmpty() )
        {
            QLabel* label = new QLabel( second, this );
            label->setAlignment( Qt::AlignCenter );
            vLayout->addWidget( label );

        }

        // separator
        QString description( event.description() );
        if( !description.isEmpty() )
        {
            QFrame* frame = new QFrame( this );
            frame->setFrameStyle( QFrame::HLine );
            vLayout->addWidget( frame );

            QLabel* label = new QLabel( description, this );
            label->setFont( QtUtil::titleFont( label->font() ) );
            if( description.indexOf( "\n" ) < 0 )
            { label->setAlignment( Qt::AlignCenter ); }

            vLayout->addWidget( label );
        }

    }

    //_________________________________________
    CalendarToolTipWidget::CalendarToolTipWidget( QWidget* parent ):
        ToolTipWidget( parent )
    { layout().setSpacing( 10 ); }

    //_________________________________________
    void CalendarToolTipWidget::addEvent( const CalendarEvent& event )
    { layout().addWidget( new CalendarToolTipWidgetItem( this, event ) ); }

    //_________________________________________
    void CalendarToolTipWidget::clear()
    {
        for( const auto& item:findChildren<CalendarToolTipWidgetItem*>() )
        { delete item; }
    }

}
