/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlarmModel.h"

namespace Clock
{

    //_______________________________________________________________________________________
    QVariant AlarmModel::data( const QModelIndex& index, int role ) const
    {

        // check index
        if( !contains( index ) ) return QVariant();

        // retrieve associated file info
        Alarm alarm( get()[index.row()] );

        // return text associated to file and column
        if( role == Qt::DisplayRole )
        {

            switch( index.column() )
            {

                case Time: return alarm.time().toString( TimeStamp::Format::Time );
                case Text: return alarm.text();
                case Days: return alarm.dayNames();
                default: return QVariant();
            }

        } else if( role == Qt::CheckStateRole && index.column() == Enabled ) {

            return alarm.enabled() ? Qt::Checked : Qt::Unchecked;

        }


        return QVariant();

    }

    //____________________________________________________________
    void AlarmModel::_sort( int column, Qt::SortOrder order )
    {

        Debug::Throw() << "OptionModel::sort - column: " << column << " order: " << order << endl;
        std::sort( _get().begin(), _get().end(), SortFTor( (ColumnType) column, order ) );

    }

    //________________________________________________________
    bool AlarmModel::SortFTor::operator () ( Alarm first, Alarm second ) const
    {

        if( order_ == Qt::DescendingOrder ) std::swap( first, second );

        switch( type_ )
        {

            case Days: return first.days() < second.days();
            case Time: return first.time() < second.time();
            case Text: return first.text() < second.text();
            default: return true;
        }

    }


    //________________________________________________________
    QVariant AlarmModel::headerData( int section, Qt::Orientation orientation, int role ) const
    {

        if( orientation == Qt::Horizontal && role == Qt::DisplayRole && section >= 0 && section < nColumns )
        { return columnTitles_[section]; }

        // return empty
        return QVariant();

    }
}
