#ifndef AlarmModel_h
#define AlarmModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Alarm.h"
#include "Counter.h"
#include "ListModel.h"

#include <array>

namespace Clock
{

    //* model
    class AlarmModel: public ListModel<Alarm>, private Base::Counter<AlarmModel>
    {

        Q_OBJECT

        public:

        //* column type enumeration
        enum ColumnType
        {
            Enabled,
            Time,
            Text,
            Days,
            nColumns
        };

        //* constructor
        explicit AlarmModel( QObject* parent = nullptr ):
            ListModel<Alarm>( parent ),
            Counter( "AlarmModel" )
        {}

        //*@name methods reimplemented from base class
        //@{

        //* flags
        Qt::ItemFlags flags(const QModelIndex& ) const override
        { return Qt::ItemIsEnabled |  Qt::ItemIsSelectable; }

        //* return data
        QVariant data(const QModelIndex &index, int role) const override;

        //* header data
        QVariant headerData(int section, Qt::Orientation, int role = Qt::DisplayRole) const override;

        //* number of columns for a given index
        int columnCount(const QModelIndex &parent = QModelIndex()) const override
        { return nColumns; }

        //@}

        protected:

        //* sort
        void _sort( int, Qt::SortOrder ) override;

        private:

        //* column names
        const std::array<QString,nColumns> columnTitles_ =
        {{
            QString(),
            tr( "Time" ),
            tr( "Text" ),
            tr( "Days" )
        }};

        //* used to sort options
        class SortFTor
        {

            public:

            //* constructor
            explicit SortFTor( ColumnType type, Qt::SortOrder order):
                type_( type ),
                order_( order )
            {}

            //* prediction
            bool operator() ( Alarm first, Alarm second ) const;

            private:

            //* column
            ColumnType type_;

            //* order
            Qt::SortOrder order_;

        };

    };
};

#endif
