#ifndef DataSamples_h
#define DataSamples_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Data.h"

#include <QList>

namespace Disk
{

    //* data samples container
    class DataSamples
    {

        public:

        //* shortcut for data list
        using DataList = QList< Data >;

        //* construtor
        explicit DataSamples( int sampleSize = 0, int dataSize = 0 ):
            sampleSize_( sampleSize ),
            dataSize_( dataSize )
        { }

        //* set sample size
        void setSampleSize( int sampleSize );

        //* set data point size
        void setDataSize( int dataSize );

        //* retrieve data
        const DataList& data() const
        { return dataList_; }

        //* add a data point
        void add( const Data& data );

        private:

        //* list of cpu load measurement
        DataList sampleList_;

        //* list of cpu load differences
        DataList dataList_;

        //* number of samples to be averaged to make the data points
        int sampleSize_ = 0;

        //* number of data point to store
        int dataSize_ = 0;

    };
};

#endif
