#ifndef ApplicationDataModel_h
#define ApplicationDataModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "ApplicationData.h"

#include <QMimeData>

#include <array>

//* Job model. Stores job information for display in lists
class ApplicationDataModel : public ListModel<ApplicationData>, private Base::Counter<ApplicationDataModel>
{

    Q_OBJECT

    public:

    //* constructor
    explicit ApplicationDataModel( QObject* = nullptr );

    //* column type enumeration
    enum ColumnType
    {
        Name,
        Position,
        Size,
        Order,
        nColumns
    };

    //*@name methods reimplemented from base class
    //@{

    //* flags
    Qt::ItemFlags flags( const QModelIndex& ) const override;

    //* data
    QVariant data( const QModelIndex&, int ) const override;

    //* header data
    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

    //* number of columns for a given index
    int columnCount( const QModelIndex& = QModelIndex() ) const override
    { return nColumns; }


    //* mime type
    QStringList mimeTypes() const override;

    //* mime data
    QMimeData* mimeData( const QModelIndexList& ) const override;

    //* drop mine data
    bool dropMimeData(const QMimeData*, Qt::DropAction, int, int, const QModelIndex&) override;

    //@}

    Q_SIGNALS:

    //* emitted via drag and drop
    void itemOrderChanged( int, int );

    private:

    //* list column names
    const std::array<QString, nColumns> columnTitles_ =
    {{
        tr( "Name" ),
        tr( "Position" ),
        tr( "Size" ),
        tr( "Order" )
    }};

};

#endif
