/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "ApplicationType.h"
#include "CppUtil.h"

//____________________________________________
ApplicationType::Map& ApplicationType::names()
{
    static Map map = Base::makeT<Map>( {
        { AppNone, QObject::tr( "unknown" ) },
        { AppAcpi, QObject::tr( "Battery Monitor" ) },
        { AppCalendar, QObject::tr( "Transparent Calendar" ) },
        { AppClock, QObject::tr( "Transparent Clock" ) },
        { AppCpu, QObject::tr( "Cpu Monitor" ) },
        { AppDisk, QObject::tr( "Disk Monitor" ) },
        { AppMemory, QObject::tr( "Memory Monitor" ) },
        { AppNetwork, QObject::tr( "Network Monitor" ) },
        { AppSummary, QObject::tr( "System Monitor Summary" ) },
        { AppTemperature, QObject::tr( "Temperature Monitor" ) }
    });
    return map;

}

//____________________________________________
ApplicationType::Map& ApplicationType::iconNames()
{
    static Map map = Base::makeT<Map>( {
        { AppNone, ":/transparency.png" },
        { AppAcpi, ":transparent-acpi.png" },
        { AppCalendar, ":/transparent-calendar.png" },
        { AppClock, ":/transparent-clock.png" },
        { AppCpu, ":/transparent-cpu-load.png" },
        { AppDisk, ":/transparent-disk-load.png" },
        { AppMemory, ":/transparent-memory-load.png" },
        { AppNetwork, ":/transparent-network-load.png" },
        { AppSummary, ":/transparent-system-monitor.png" },
        { AppTemperature, ":/transparency.png" }
    });
    return map;

}

//____________________________________________
ApplicationType::Set ApplicationType::Helper::set( const CommandLineParser& parser )
{
    Set out;
    bool all( parser.hasFlag( "--all" ) );
    if( all || parser.hasFlag( "--acpi" ) ) out.insert( ApplicationType::AppAcpi );
    if( all || parser.hasFlag( "--calendar" ) ) out.insert( ApplicationType::AppCalendar );
    if( all || parser.hasFlag( "--clock" ) ) out.insert( ApplicationType::AppClock );
    if( all || parser.hasFlag( "--cpu" ) ) out.insert( ApplicationType::AppCpu );
    if( all || parser.hasFlag( "--disk" ) ) out.insert( ApplicationType::AppDisk );
    if( all || parser.hasFlag( "--memory" ) ) out.insert( ApplicationType::AppMemory );
    if( all || parser.hasFlag( "--network" ) ) out.insert( ApplicationType::AppNetwork );
    if( all || parser.hasFlag( "--summary" ) ) out.insert( ApplicationType::AppSummary );
    if( all || parser.hasFlag( "--temperature" ) ) out.insert( ApplicationType::AppTemperature );
    return out;
}

//____________________________________________
ApplicationType::Set ApplicationType::Helper::set( int mask )
{
    Set out;
    if( mask & AppAcpi ) out.insert( ApplicationType::AppAcpi );
    if( mask & AppCalendar ) out.insert( ApplicationType::AppCalendar );
    if( mask & AppClock ) out.insert( ApplicationType::AppClock );
    if( mask & AppCpu ) out.insert( ApplicationType::AppCpu );
    if( mask & AppDisk ) out.insert( ApplicationType::AppDisk );
    if( mask & AppMemory ) out.insert( ApplicationType::AppMemory );
    if( mask & AppNetwork ) out.insert( ApplicationType::AppNetwork );
    if( mask & AppSummary ) out.insert( ApplicationType::AppSummary );
    if( mask & AppTemperature ) out.insert( ApplicationType::AppTemperature );
    return out;
}

//______________________________________
int ApplicationType::Helper::toInt( const ApplicationType::Set& set )
{
    int out( ApplicationType::AppNone );
    for( const auto& type:set ) { out |= type.type(); }
    return out;
}
