#ifndef GeometryApplication_h
#define GeometryApplication_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationData.h"
#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"
#include "IconEngine.h"

class GeometryDialog;

//* Main Window singleton object
class GeometryApplication: public BaseApplication, private Base::Counter<GeometryApplication>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit GeometryApplication( CommandLineArguments );

    //* destructor
    ~GeometryApplication() override;

    //* create all widgets
    bool realizeWidget() override;

    //* cvs log frame
    GeometryDialog& mainWindow() const
    { return *mainWindow_; }

    //*@name application information
    //@{

    //* command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const override;

    //* usage
    void usage() const override;

    //* application name
    QString applicationName() const override
    { return "Transparency-settings"; }

    //* application icon
    QIcon applicationIcon() const override
    { return IconEngine::get( ":/transparency.png" ); }

    // application version
    QString applicationVersion() const override
    { return VERSION; }

    //@}

    protected Q_SLOTS:

    //* Send request to all transparency application for raise
    void _sendGeometryRequest();

    //* update geometry
    /* perform the necessary geometry calculations based on default layout and send */
    void _updateGeometry();

    //* send geometry
    void _sendGeometry( ApplicationData );

    //* configuration
    void _configuration();

    public Q_SLOTS:

    //* command
    bool _processCommand( Server::ServerCommand ) override;

    private:

    //* request
    void _sendRequest( Server::ServerCommand::CommandType );

    //* main window
    GeometryDialog *mainWindow_ = nullptr;

    //* local application data list
    ApplicationData::List applications_;

};

#endif
