#ifndef GeometryDialog_h
#define GeometryDialog_h
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationDataModel.h"
#include "CustomDialog.h"
#include "OptionAnchorWidget.h"
#include "OptionComboBox.h"
#include "OptionSpinBox.h"
#include "OptionWidgetList.h"

#include <QPushButton>

class TreeView;

//* list transparency applications geometry
class GeometryDialog: public CustomDialog, public OptionWidgetList
{

    //* Qt meta object declaration
    Q_OBJECT;

    public:

    //* constructor
    explicit GeometryDialog( QWidget* = nullptr );

    //* application data
    void add( ApplicationData );

    Q_SIGNALS:

    //* modified
    void modified();

    //* geometry requested
    void geometryRequested();

    //* geometry changed
    void geometryChanged( ApplicationData );

    public Q_SLOTS:

    //* reload document classes
    void reload();

    protected Q_SLOTS:

    //* update buttons
    void _updateButtons();

    //* edit
    void _edit();

    //* apply
    void _apply( bool = true );

    //* apply
    void _applyUnchecked()
    { _apply( false ); }

    //* restore default
    void _restoreDefaults();

    //* move up selected task
    void _up();

    //* move down selected task
    void _down();

    //* reorder
    void _reorder( int, int );

    //* sort
    void _sort( int );

    //* sort
    void _sort();

    private Q_SLOTS:

    //* configuration
    void _updateConfiguration();

    //* configuration
    void _saveConfiguration();

    private:

    //* model
    ApplicationDataModel model_;

    //* backup
    ApplicationDataModel::List backup_;

    //* document classes list
    TreeView* list_ = nullptr;

    //* edit
    QPushButton* edit_ = nullptr;

    //* move up
    QPushButton* up_ = nullptr;

    //* move down
    QPushButton* down_ = nullptr;

    //* reload
    QPushButton* reload_ = nullptr;

    //*@name reorganization configuration
    //@{

    //* alignment
    OptionComboBox* alignmentComboBox_ = nullptr;

    //* anchor
    OptionAnchorWidget* anchorWidget_ = nullptr;

    //* offset
    OptionSpinBox* horizontalOffsetSpinBox_ = nullptr;

    //* offset
    OptionSpinBox* verticalOffsetSpinBox_ = nullptr;

    //* spacing
    OptionSpinBox* spacingSpinBox_ = nullptr;

    //* apply button
    QPushButton* apply_ = nullptr;

    //@}

};

#endif
