#ifndef HistogramWidget_h
#define HistogramWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MainWindow.h"

#include <QAction>
#include <QIcon>
#include <QLinearGradient>
#include <QPainter>
#include <QBasicTimer>
#include <QTimerEvent>

//* transparent histogram widget
class HistogramWidget : public MainWindow
{

    //* Qt meta object functions
    Q_OBJECT

    public:

    //* constructor
    explicit HistogramWidget( QWidget* = nullptr );

    protected:

    //* context menu
    void _installContextMenuActions( BaseContextMenu* );

    //* draw load text
    void _paintHost( QPainter&, QRect& );

    //* paint text
    void _paintText( QPainter&, const QString&, QRect& );

    //* host name
    const QString& _hostName() const
    { return hostName_; }

    //*@name actions
    //@{

    //* host
    QAction& _showHostAction() const
    { return *showHostAction_; }

    //* load
    QAction& _showLoadAction() const
    { return *showLoadAction_; }

    //@}

    protected Q_SLOTS:

    //* update configuration
    virtual void _updateConfiguration();

    //* show load
    virtual void _toggleShowHost( bool );

    //* show host
    virtual void _toggleShowLoad( bool );

    private:

    //* install actions
    void _installActions();

    //*@name actions
    //@{

    //* show host
    QAction* showHostAction_ = nullptr;

    //* show load
    QAction* showLoadAction_ = nullptr;

    //@}

    //*@name properties
    //@{

    //* application hostname
    QString hostName_;

    //@}

};

#endif
