#ifndef MainWindow_h
#define MainWindow_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "TransparentWindow.h"

#include <QTimerEvent>

// forward declaration
class ConfigurationDialog;
class BaseToolTipWidget;

//* transparent MainWindow widget
class MainWindow : public TransparentWindow
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit MainWindow( QWidget* = nullptr );

    //*@name actions
    //@{

    //* raise all
    QAction& _raiseAllAction() const
    { return *raiseAllAction_; }

    //* close all
    QAction& _closeAllAction() const
    { return *closeAllAction_; }

    //@]

    protected:

    //*@name event handlers
    //@{

    //* generic event handler
    bool event( QEvent* ) override;

    //* timer event
    void timerEvent( QTimerEvent* ) override;

    //* mouse move event [overloaded]
    void mousePressEvent( QMouseEvent* ) override;

    //* double click event
    void mouseDoubleClickEvent( QMouseEvent* ) override;

    //@}

    //* context menu
    void _installContextMenuActions( BaseContextMenu* ) override;

    //* tooltip widget
    BaseToolTipWidget* _toolTipWidget();

    //* tooltip widget
    virtual BaseToolTipWidget* _createToolTipWidget();

    //* update widget tooltip, if any
    virtual bool _updateToolTip()
    { return false; }

    //* update widget tooltip, if any
    virtual bool _updateToolTip( const QPoint& )
    { return false; }

    //* update timer
    virtual QBasicTimer& _updateTimer()
    { return updateTimer_; }

    //* refresh
    virtual int _refresh() const
    { return refresh_; }

    protected Q_SLOTS:

    //* update configuration
    void _updateConfiguration() override;

    private:

    //* install actions
    void _installActions();

    //* tooltip widget
    BaseToolTipWidget* toolTipWidget_ = nullptr;

    //* timer to redraw
    QBasicTimer updateTimer_;

    //* update delay (second)
    int refresh_ = 5;

    //*@name actions
    //@{

    //* raise all action
    QAction* raiseAllAction_ = nullptr;

    //* close all action
    QAction* closeAllAction_ = nullptr;

    //@}


};


#endif
