#ifndef PictureApplication_h
#define PictureApplication_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Counter.h"
#include "IconEngine.h"

namespace Pictures { class PictureWidget; }

//* Main Window singleton object
class PictureApplication: public BaseApplication, private Base::Counter<PictureApplication>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit PictureApplication( CommandLineArguments );

    //* create all widgets
    bool realizeWidget() override;

    //*@name actions
    //@{

    //* raise all
    QAction& raiseAllAction() const
    { return *raiseAllAction_; }

    //* new picture
    QAction& newPictureAction() const
    { return *newPictureAction_; }

    //* picture list
    QAction& pictureListAction() const
    { return *pictureListAction_; }

    //* aspect ratio
    QAction& keepAspectRatioAction() const
    { return *keepAspectRatioAction_; }

    //* toggle filename action
    QAction& showFilenameAction() const
    { return *showFileNameAction_; }

    //@}

    //*@name application information
    //@{

    //* usage
    void usage() const override;

    //* application name
    QString applicationName() const override;

    //* application icon
    QIcon applicationIcon() const override
    { return IconEngine::get( ":/transparent-picture-viewer.png" ); }

    // application version
    QString applicationVersion() const override;

    //@}

    protected Q_SLOTS:

    //* configuration
    void _configuration() override;

    //* process request from application manager
    bool _processCommand( Server::ServerCommand ) override;

    private Q_SLOTS:

    //* raise all
    void _raiseAll();

    //* configuration
    void _updateConfiguration();

    //* write pictures from resource files
    void _writePictures(  bool check = true );

    //* create a new task bar from attributes
    void _newPicture();

    //* picture list
    void _showPictureList();

    //* picture is destroyed
    void _pictureDestroyed( QObject* );

    //* toggle aspect ratio
    void _toggleKeepAspectRatio( bool );

    //* toggle filename
    void _toggleShowFilename( bool );

    //* one picture has been hidden
    void _pictureHidden();

    private:

    //* actions
    void _installActions();

    //* add a picture
    void _addPicture( Pictures::PictureWidget* );

    //* read pictures from resource files
    void _readPictures();

    //* picture widgets
    QList<Pictures::PictureWidget*> pictureWidgets_;

    //*@name actions
    //@{

    //* raise all action
    QAction* raiseAllAction_ = nullptr;

    //* new picture
    QAction* newPictureAction_ = nullptr;

    //* picture list
    QAction* pictureListAction_ = nullptr;

    //* aspect ratio
    QAction* keepAspectRatioAction_ = nullptr;

    //* filename
    QAction* showFileNameAction_ = nullptr;

    //@}

};

#endif
