#ifndef NetworkWidget_h
#define NetworkWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "GridLayoutItem.h"
#include "HistogramWidget.h"
#include "NetworkMonitor.h"

#include <QAction>
#include <QActionGroup>
#include <QBasicTimer>
#include <QHash>
#include <QPainter>
#include <QTimerEvent>

//* network widgets
namespace Network {

    //* transparent network load widget
    class NetworkWidget : public HistogramWidget
    {

        //* Qt meta object functions
        Q_OBJECT

        public:

        //* constructor
        explicit NetworkWidget( QWidget* = nullptr );

        //* tooltip
        bool _updateToolTip() override;

        protected Q_SLOTS:

        //* opend configuration dialog
        void _configuration() override;

        //* update configuration
        void _updateConfiguration() override;

        //* toggle inverse colors
        void _toggleInverseColors( bool ) override;

        //* toggle display
        void _toggleDisplay( QAction* );

        protected:

        //* context menu
        void _installContextMenuActions( BaseContextMenu* ) override;

        //* tooltip widget
        BaseToolTipWidget* _createToolTipWidget() override;

        //*@name event handlers
        //@{

        //* timer
        void timerEvent( QTimerEvent* ) override;

        //* paint event [overloaded]
        void _paint( QPaintDevice&, const QRect& );

        //* resize event [overloaded]
        void resizeEvent( QResizeEvent* ) override;

        //@}

        //* scale factor
        double _getScale( const NetworkLoad::DataList& ) const;

        //* draw load text
        void _paintLoad( QPainter&, QRect& );

        //* set default colors
        void _setDefaultColors();

        private:

        //* install actions
        void _installActions();

        //* update display actions from mask
        void _updateDisplayActions();

        //* network object
        NetworkMonitor networkMonitor_;

        //*@name actions
        //@{

        //* display actions
        QActionGroup* displayActionGroup_ = nullptr;

        //* display actions
        using DisplayActionMap = QHash<QAction*, NetworkLoad::DataType>;

        //* display actions
        DisplayActionMap displayActions_;

        //@}

        //*@name properties
        //@{

        //* display mask
        NetworkLoad::DataTypes displayMask_ = NetworkLoad::All;

        //* color map
        using ColorMap = QHash< NetworkLoad::DataType, Color >;

        //* color map
        ColorMap colorMap_;

        //@}

        //* tooltip items
        GridLayoutItem::List toolTipItems_;

    };
}

#endif
