/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureAttributes.h"

#include "CppUtil.h"
#include "Debug.h"
#include "PictureXmlDef.h"
#include "XmlTimeStamp.h"

namespace Pictures
{

    //_____________________________________________
    const File PictureAttributes::NoPicture = File( "none" );

    //_____________________________________________
    PictureAttributes::PictureAttributes(  const QDomElement& element ):
        Counter( "PictureAttributes" )
    {

        Debug::Throw( "PictureAttributes::PictureAttributes.\n" );

        // parse attributes
        QDomNamedNodeMap attributes( element.attributes() );
        for( int i=0; i<attributes.count(); i++ )
        {
            QDomAttr attribute( attributes.item( i ).toAttr() );
            if( attribute.isNull() ) continue;
            else if( attribute.name() == Xml::X ) position_.setX( attribute.value().toInt() );
            else if( attribute.name() == Xml::Y ) position_.setY( attribute.value().toInt() );
            else if( attribute.name() == Xml::Width ) size_.setWidth( attribute.value().toInt() );
            else if( attribute.name() == Xml::Height ) size_.setHeight( attribute.value().toInt() );
            else if( attribute.name() == Xml::Filename ) setFilename( File( attribute.value() ) );
            else if( attribute.name() == Xml::Visibility ) setVisible( attribute.value().toInt() );
            else Debug::Throw(0) << "PictureAttributes::PictureAttributes - unrecognized entry attribute: \"" << attribute.name() << "\"\n";
        }

    }


    //______________________________________________________________________
    QDomElement PictureAttributes::domElement( QDomDocument& document ) const
    {
        Debug::Throw( "PictureAttributes::domElement.\n" );

        QDomElement out( document.createElement( Xml::Picture ) );
        out.setAttribute( Xml::X, QString::number( position().x() ) );
        out.setAttribute( Xml::Y, QString::number( position().y() ) );
        out.setAttribute( Xml::Width, QString::number( size().width() ) );
        out.setAttribute( Xml::Height, QString::number( size().height() ) );
        out.setAttribute( Xml::Filename, filename() );
        out.setAttribute( Xml::Visibility, QString::number( isVisible() ) );
        return out;
    }

    //____________________________________________________________________
    bool operator < (const PictureAttributes& first, const PictureAttributes& second )
    {
        if( first.filename() != second.filename() ) return first.filename() < second.filename();
        if( first.size().width() != second.size().width() ) return first.size().width() < second.size().width();
        if( first.size().height() != second.size().height() ) return first.size().height() < second.size().height();
        if( first.position().x() != second.position().x() ) return first.position().x() < second.position().x();
        if( first.position().y() != second.position().y() ) return first.position().y() < second.position().y();
        return false;
    }

    //____________________________________________________________________
    bool operator == (const PictureAttributes& first, const PictureAttributes& second)
    {
        return
            first.filename() == second.filename() &&
            first.size() == second.size() &&
            first.position() == second.position();
    }

}
