/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureAttributesModel.h"

#include "CustomPixmap.h"
#include "File.h"
#include "XmlOptions.h"

namespace Pictures
{
    //__________________________________________________________________
    PictureAttributesModel::IconCache& PictureAttributesModel::_icons()
    {
        static IconCache cache;
        return cache;
    }

    //_______________________________________________________________________________________
    QVariant PictureAttributesModel::data( const QModelIndex& index, int role ) const
    {

        // check index
        if( !contains( index ) ) return QVariant();

        // retrieve associated file info
        PictureAttributes attributes( get()[index.row()] );

        // return text associated to file and column
        if( role == Qt::DisplayRole && index.column() == Filename )
        {

            return File( attributes.filename() ).localName().get();

        } else if( role == Qt::CheckStateRole && index.column() == Visibility ) {

            return attributes.isVisible() ? Qt::Checked:Qt::Unchecked;

        } else if( role == Qt::DecorationRole && index.column() == Icon ) {

            return _icon( attributes.filename() );

        } else if( role == Qt::ToolTipRole ) return attributes.filename().get();

        return QVariant();

    }

    //________________________________________________________
    QVariant PictureAttributesModel::headerData( int section, Qt::Orientation orientation, int role ) const
    {

        if( orientation == Qt::Horizontal && role == Qt::DisplayRole && section >= 0 && section < nColumns )
        { return columnTitles_[section]; }

        // return empty
        return QVariant();

    }

    //________________________________________________________
    QIcon PictureAttributesModel::_icon( const QString& filename )
    {

        IconCache::const_iterator iter( _icons().find( filename ) );
        if( iter != _icons().end() ) return iter.value();

        // pixmap size
        int pixmapSize = XmlOptions::get().get<int>( "LIST_ICON_SIZE" );
        QSize size( pixmapSize, pixmapSize );
        QSize scale(size*0.9);

        QPixmap base( filename );

        QIcon icon;
        if( !base.isNull() )
        { icon = CustomPixmap( size, CustomPixmap::Flag::All ).merged( base.scaled( scale, Qt::KeepAspectRatio, Qt::SmoothTransformation ), CustomPixmap::Corner::Center ); }

        // insert in map
        _icons().insert( filename, icon );

        return icon;

    }
}
