#ifndef PictureAttributesModel_h
#define PictureAttributesModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureAttributes.h"
#include "Counter.h"
#include "ListModel.h"

#include <QIcon>
#include <QString>

#include <array>

namespace Pictures
{

    //* model
    class PictureAttributesModel: public ListModel<PictureAttributes>, private Base::Counter<PictureAttributesModel>
    {

        Q_OBJECT

        public:

        //* column type enumeration
        enum ColumnType
        {
            Icon,
            Filename,
            Visibility,
            nColumns
        };

        //* constructor
        explicit PictureAttributesModel( QObject* parent = 0 ):
            ListModel<PictureAttributes>( parent ),
            Counter( "PictureAttributesModel" )
        {}

        //*@name methods reimplemented from base class
        //@{

        //* flags
        Qt::ItemFlags flags( const QModelIndex& ) const override
        { return Qt::ItemIsEnabled |  Qt::ItemIsSelectable; }

        //* return data
        QVariant data( const QModelIndex&, int ) const override;

        //* header data
        QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

        //* number of columns for a given index
        int columnCount( const QModelIndex& = QModelIndex() ) const override
        { return nColumns; }

        //@}

        //* clear icon cache
        static void clearIconCache()
        { _icons().clear(); }

        private:

        //* icon
        static QIcon _icon( const QString& );

        //* icon cache
        using IconCache = QHash<QString, QIcon>;

        //* type icon cache
        static IconCache& _icons();

        //* column names
        const std::array<QString, nColumns> columnTitles_ =
        {{
            QString(),
            tr( "File " ),
            QString()
        }};

    };

};
#endif
